# NiveshPy

NiveshPy is a financial CLI designed for managing mutual funds and investment portfolios. It provides functionalities to fetch fund prices, manage portfolios, and calculate performance.

**Documentation**: [http://yashovardhan99.github.io/niveshpy](http://yashovardhan99.github.io/niveshpy)

NiveshPy is targeted towards Indian :india: markets, but the API is built to support any financial security.

## Quick Start

To get started, install NiveshPy from [PyPi](https://pypi.org/project/NiveshPy/):

```sh
pip install niveshpy
```

After installing, you can simply start using NiveshPy:

```sh
niveshpy <command>
```

Learn more by checking our [CLI documentation](http://yashovardhan99.github.io/niveshpy/cli)

## Work in progress

This project is a work in progress. The public API is still in development and unstable.

## License

This project is licensed under the MIT License. See the [LICENSE](LICENSE) file for more details.
